@@ -2,21 +2,20 @@ import pandas as pd
 import requests
 
 
-
 def get_data(data_set):
 
    extension = '.csv'
-   dir_name =  'https://raw.githubusercontent.com/maker57sk/aimluae/main/datasets/'
+   dir_name =  'https://raw.githubusercontent.com/aimluae/uaedata/main/datasets/'
    filename = dir_name + data_set + extension
 
    if requests.get(filename).status_code == 200:
-      df = pd.read_csv(filename)
-      return print(df.head())
+      return pd.read_csv(filename)
+      
    else:
       extension = '.xlsx'
       filename = dir_name + data_set + extension
-      df = pd.read_excel(filename)
-      return print(df.head())
+      return pd.read_excel(filename)
+ 
 
 def list_datasets():
    data_sets = [
@@ -25,6 +24,3 @@ def list_datasets():
       'livebirths', 'Services-En_0', 'vehicle_clearance_certificate', 'UAE_National_Red List_Species',
    ]
    return data_sets
-
-
-get_data('customs_warehouse_licensees')
\ No newline at end of file
